@@ -4,6 +4,7 @@
 
     Copyright (C) 2002 Adriaan de Groot <groot@kde.org>
     Copyright (C) 2004, 2005 Nicolas GOUTTE <goutte@kde.org>
+    Copyright (C) 2015, 2016 Wolfgang Bauer <wbauer@tmo.at>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -45,7 +46,7 @@ static QString extPath = QString();
 		extPath = path;
 	}
 
-	return KGlobal::dirs()->findExe(e, extPath);
+	return KStandardDirs::findExe(e, extPath);
 }
 
 
